4.21. umbra.components.factory.scriptEditor.searchInFiles — Umbra 1.0.9 documentation

# 4.21. umbra.components.factory.scriptEditor.searchInFiles

searchInFiles.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `SearchInFiles` class.

Others:

## 4.21.1. Module Attributes

`umbra.components.factory.scriptEditor.searchInFiles.` `LOGGER`

`umbra.components.factory.scriptEditor.searchInFiles.` `UI_FILE`

## 4.21.2. Classes

class `umbra.components.factory.scriptEditor.searchInFiles.` `SearchInFiles`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  Defines search and replace in files dialog used by the ScriptEditor Component.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `scriptEditor`

    Property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor.
    Return type: | QWidget

  `filesCache`

    Property for self.__filesCache attribute.

    Returns: | self.__filesCache.
    Return type: | Cache

  `searchPatternsModel`

    Property for self.__searchPatternsModel attribute.

    Returns: | self.__searchPatternsModel.
    Return type: | PatternsModel

  `replaceWithPatternsModel`

    Property for self.__replaceWithPatternsModel attribute.

    Returns: | self.__replaceWithPatternsModel.
    Return type: | PatternsModel

  `model`

    Property for self.__model attribute.

    Returns: | self.__model.
    Return type: | SearchResultsModel

  `view`

    Property for self.__view attribute.

    Returns: | self.__view.
    Return type: | QWidget

  `delegate`

    Property for self.__delegate attribute.

    Returns: | self.__delegate.
    Return type: | QItemDelegate

  `locations`

    Property for self.__locations attribute.

    Returns: | self.__locations.
    Return type: | OrderedDict

  `locationsMenu`

    Property for self.__locationsMenu attribute.

    Returns: | self.__locationsMenu.
    Return type: | QMenu

  `defaultFilterIn`

    Property for self.__defaultFilterIn attribute.

    Returns: | self.__defaultFilterIn.
    Return type: | unicode

  `filtersInFormat`

    Property for self.__filtersInFormat attribute.

    Returns: | self.__filtersInFormat.
    Return type: | unicode

  `defaultFilterOut`

    Property for self.__defaultFilterOut attribute.

    Returns: | self.__defaultFilterOut.
    Return type: | unicode

  `filtersOutFormat`

    Property for self.__filtersOutFormat attribute.

    Returns: | self.__filtersOutFormat.
    Return type: | unicode

  `defaultTarget`

    Property for self.__defaultTarget attribute.

    Returns: | self.__defaultTarget.
    Return type: | unicode

  `targetsFormat`

    Property for self.__targetsFormat attribute.

    Returns: | self.__targetsFormat.
    Return type: | unicode

  `defaultLineNumberWidth`

    Property for self.__defaultLineNumberWidth attribute.

    Returns: | self.__defaultLineNumberWidth.
    Return type: | int

  `defaultLineColor`

    Property for self.__defaultLineColor attribute.

    Returns: | self.__defaultLineColor.
    Return type: | QColor

  `ignoreHiddenFiles`

    Property for self.__ignoreHiddenFiles attribute.

    Returns: | self.__ignoreHiddenFiles.
    Return type: | bool

  `searchWorkerThread`

    Property for self.__searchWorkerThread attribute.

    Returns: | self.__searchWorkerThread.
    Return type: | QThread

  `show`()

    Reimplements the `QWidget.show()` method.

  `closeEvent`(event)

    Reimplements the `QWidget.closeEvent()` method.

    Parameters: | event (QEvent) – QEvent.

  `setSearchResults`(searchResults)

    Sets the Model Nodes using given search results.

    Parameters: | searchResults (list) – Search results.
    Returns: | Method success.
    Return type: | bool

  `setReplaceResults`(replaceResults)

    Sets the Model Nodes using given replace results.

    Parameters: | replaceResults (list) – Replace results.
    Returns: | Method success.
    Return type: | bool

  `search`()

    Searchs user defined locations for search pattern.

    Returns: | Method success.
    Return type: | bool

  `replace`(nodes)

    Replaces user defined files search pattern occurrences with replacement pattern using given nodes.

    Parameters: | nodes (list) – Nodes.
    Returns: | Method success.
    Return type: | bool

  `saveFiles`(nodes)

    Saves user defined files using give nodes.

    Parameters: | nodes (list) – Nodes.
    Returns: | Method success.
    Return type: | bool